%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  UNCERTAINTIES class for LaTeX files      v1. Apr-12-2006 (P.S.Varoto and M.A.Trindade) / v2. SWGE May-05-2014
%%      v3. SWGE Aug-27-2015
%%                                                                
%% The regular article class commands still exist and may be used
%% 11pt, 12pt and twocolumn options are disabled.                
%%                                                               
%% \maketitle make the first page automatically                 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{uncertainties}[2015/08/27 UNCERTAINTIES paper class]

\DeclareOption{11pt}{\OptionNotUsed}
\DeclareOption{12pt}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\DeclareOption{dvips}{%
  \PassOptionsToPackage{dvips}{graphicx}}
\DeclareOption{pdftex}{%
  \PassOptionsToPackage{pdftex}{graphicx}}
\DeclareOption{dvipdfm}{%
  \PassOptionsToPackage{dvipdfm}{graphicx}}

\ProcessOptions\relax

\LoadClass[a4paper,10pt,twoside]{article}

\RequirePackage{graphicx}
%\RequirePackage{mathptmx}
\RequirePackage{times}
\RequirePackage{colortbl}

\newcommand{\email}[1]{\gdef\@email{#1}}
\arrayrulecolor{black}
\doublerulesep 0.7pt
\doublerulesepcolor{black}

%% Title
\renewcommand{\maketitle}{%
 \newpage
 \thispagestyle{empty}
 ~\\[-34pt]
 \noindent
 \begin{minipage}[t][22mm][t]{\textwidth}
  \begin{flushleft}
   \fontsize{9}{11}\selectfont
   \sf

	Proceedings of the 3rd International Symposium on Uncertainty Quantification and Stochastic Modeling \\
	D.A. Rade; A. M. G. Lima (Editors), ABCM, Maresias, SP, Brazil, February 15-19, 2016

  \end{flushleft}
 \end{minipage}
 ~\\[-10pt]
 \begin{tabular}{||p{168mm}}
  \vspace{1pt}  
  {%3
   \fontsize{16}{18}\selectfont
   {\sf
   \@title}
   \par
  }%3
  \vspace{14pt}%
  {%4
   \fontsize{9}{10}\selectfont
   {\sf \bfseries
   \@author}
   \par
  }%4
  \vspace{13pt}%
  {%5
   \fontsize{9}{10}\selectfont
   {\sf
   \@address}
   \par
  }%5
  \vspace{12pt}%
  \fontsize{10}{11}\selectfont
  \noindent\textit{Abstract: }{\textit\@abstract}
  \par
  \vspace{4pt}%
  \fontsize{10}{11}\selectfont
  \noindent\textbf{\textit{Keywords: }}{\textbf{\textit\@keywords}}
 \end{tabular}
}% End of \@maketitle

\def\author{\@ifnextchar[{\@getshortauthor}{\@getauthor}}
\def\@getauthor#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\def\@getshortauthor[#1]#2{\gdef\@shortauthor{#1}\gdef\@author{#2}}

\newcommand{\address}[1]{\gdef\@address{#1}}

\newcommand{\keywords}[1]{\gdef\@keywords{#1}}

\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}

\newcommand{\shorttitle}[1]{\gdef\@shorttitle{#1}}

\newcommand{\shortauthors}[1]{\gdef\@shortauthors{#1}}

\def\ps@myheadings{%
    \def\@evenfoot{}%
    \def\@oddfoot{}%
    \def\@evenhead{%
        \parbox[t][18pt][t]{\textwidth}{%
        \flushleft
        \sf
        \fontsize{9}{10}\selectfont
        \textit{\@shorttitle}\\
     }
    }%
    \def\@oddhead{%
        \parbox[t][18pt][t]{\textwidth}{%
        \flushright
        \sf
        \fontsize{9}{10}\selectfont
        \textit{\@shortauthors}\\
     }
    }%
}

\def\fsectionLevel{1}
\def\fsectionIndent{0pt}
\def\fsectionSpaceBefore{10pt}
\def\fsectionSpaceAfter{1pt}
\def\fsectionStyle{\fontsize{11}{12}\selectfont\sf\bfseries\MakeUppercase}

\renewcommand{\section}{%
  \@startsection{section}{\fsectionLevel}{\fsectionIndent}{\fsectionSpaceBefore}%
                {\fsectionSpaceAfter}{\fsectionStyle}}%

\def\ssectionLevel{2}
\def\ssectionIndent{0pt}
\def\ssectionSpaceBefore{5pt}
\def\ssectionSpaceAfter{1pt}
\def\ssectionStyle{\fontsize{11}{12}\selectfont\sffamily\bfseries}

\renewcommand{\subsection}{%
  \@startsection{subsection}{\ssectionLevel}{\ssectionIndent}{\ssectionSpaceBefore}%
                {\ssectionSpaceAfter}{\ssectionStyle}}%

\def\tsectionLevel{3}
\def\tsectionIndent{0pt}
\def\tsectionSpaceBefore{5pt}
\def\tsectionSpaceAfter{1pt}
\def\tsectionStyle{\normalsize\sffamily\itshape}

\renewcommand{\subsubsection}{%
  \@startsection{subsubsection}{\tsectionLevel}{\tsectionIndent}{\tsectionSpaceBefore}%
                {\tsectionSpaceAfter}{\tsectionStyle}}%

\renewcommand{\@makecaption}[2]{%
  \centering
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\small\sf\bfseries\fontsize{9}{10}\selectfont #1 -- #2}%
  \ifdim \wd\@tempboxa >\hsize
    \small\sf\bfseries\fontsize{9}{10}\selectfont #1 -- #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\setlength{\oddsidemargin}{-5.4mm}
\setlength{\evensidemargin}{-5.4mm}
\setlength{\topmargin}{-27mm}
\setlength{\headheight}{10mm}
\setlength{\headsep}{11mm}
\setlength{\textheight}{257mm}
\setlength{\textwidth}{170mm}
\setlength{\textfloatsep}{12pt}
\setlength{\abovedisplayskip}{6pt}
\setlength{\belowdisplayskip}{6pt}
\setlength{\parindent}{5mm}
\setlength{\parskip}{5pt}
\setlength{\abovecaptionskip}{10pt}
\setlength{\belowcaptionskip}{10pt}
\setlength{\itemsep}{0pt}

\AtBeginDocument{%
  \pagestyle{myheadings}
  \maketitle
  \let\maketitle\relax
}

\endinput
